************************************************************************************
***Appendix Table 13: Social welfare simulations -- PKH ****************************
***Additional model from Table 7 ***************************************************
************************************************************************************


clear
clear matrix
clear mata
set more off
set mem 256m
set sortseed 10000

**************************************
*1. Average benefits by program prep**
**************************************

*** PKH ***
* Kids
use "$originaldata/Baseline/hh_ar2",clear
gen count_inprimarysch=0
replace count_inprimarysch=1 if ar19==1 & ar17==2
gen count_inmiddlesch=0
replace count_inmiddlesch=1 if ar19==1 & ar17==3
collapse (sum) count_inprimarysch count_inmiddlesch, by(hhid)
tempfile childeduc
save `childeduc',replace

* More on kids
use "$originaldata/Baseline/hh_kp1",clear
replace kp10=0 if kp10==3
replace kp01=0 if kp01==3
rename kp10 havechild
rename kp01 pregnancy
tempfile hh_kp1
save `hh_kp1',replace





**************************************
*2. Input main data*******************
**************************************

*** Benefits data ***
use "$codeddata/Baseline/historical_getbenefit.dta", clear

*** Other ***
merge 1:1 hhid using "$codeddata/Baseline/matched_baseline_hybrid.dta"
assert _merge==3
drop _merge

*** Elites ***
merge 1:1 hhid using "$codeddata/Baseline/elite_measures.dta"
keep if _merge==3
drop _merge

*** Other ***
merge 1:1 hhid using "$codeddata/Baseline/allvar.dta"
assert _merge==3
drop _merge

*** PKH tempfiles ***
merge 1:1 hhid using `childeduc'
keep if _merge==3
drop _merge
merge 1:1 hhid using `hh_kp1'
keep if _merge==3
drop _merge





**************************************
*3. Coding****************************
**************************************

gen urban=(clas==1)
rename elite_self elite_related_4
rename elite_formal elite_related_5
rename elite_informal elite_related_6
rename elite_self_formal elite_related_7
rename elite_self_informal elite_related_8

local independent "PMTSCORE loghhsize sharekids hhrelated fam_outside relig_participate projects_participation contribute_money hardworking friendly total_savings share_banksavings share_debt ethnic_minority religious_minority hh_eleorless hhwidow disabled death sick income_shock tobacco_alcohol"

*restrict sample to non-missings*
replace hhrelated=0 if hhrelated==.

ren getbenefit getbenefit_pkh



**************************************
*4. Benefit amounts*******************
**************************************

*** PKH ***
gen hh_benefit_pkh=200000 // baseline
replace hh_benefit_pkh=hh_benefit_pkh+800000 if havechild==1|pregnancy==1
replace hh_benefit_pkh=hh_benefit_pkh+400000*count_inprimarysch 
replace hh_benefit_pkh=hh_benefit_pkh+800000*count_inmiddlesch
replace hh_benefit_pkh=600000 if hh_benefit_pkh<600000
replace hh_benefit_pkh=2200000 if hh_benefit_pkh>2200000
replace hh_benefit_pkh = hh_benefit_pkh/12
	la var hh_benefit_pkh "monthly HH benefit"








*****************************************************************
*5. Utility calculation, looping over benefits*******************
*****************************************************************

* Note: There are 6 scenarios:
* u_0: no program
* u_1: with elite capture
* u_2: without elite capture
* u_3: poorest on PMT
* u_4: poorest on consumption
* u_5: PPLS list and then poorest on PMT score

*****************************************************************
* a. Only one benefit SKIP SECTION ******************************


*****************************************************************
* b. Prepare ****************************************************

*** Drop missings ***
probit getbenefit_pkh elite_related_1 logconsumption `independent'
predict p1 // with elite
keep if p1!=.
drop p1
 
*** HH utilities with and without benefit ***
gen consumption_got=consumption + hh_benefit_pkh/hhsize
gen u_got=hhsize*(consumption_got^(-2)/(-2))
gen u_not=hhsize*(consumption^(-2)/(-2))



*****************************************************************
* c. Loop elites ************************************************

forv y = 1/3 {
local h : word `y' of 1 5 6
local i : word `y' of A B C
*Version 1: All elites
*Version 2: Formal elites
*Version 3: Informal elites
preserve

*****************************************************************
* d. Scenario 0 *************************************************

gen u_0=hhsize*(consumption^(-2)/(-2))



*****************************************************************
* e. Scenarios 1 and 2 ******************************************

*** Probit model, real world ***
probit getbenefit_pkh elite_related_`h' logconsumption `independent'
predict p1

*** Hypothetical model without elite relation ***
gen flag_elite_`h'=elite_related_`h'   // generate a flag of being elite related
replace elite_related_`h'=0
predict p2

*** Scale across real and hypothetical model ***
sum p1
local mean_p1=`r(mean)'
sum p2
local mean_p2=`r(mean)'
local ratio=`mean_p1'/`mean_p2'
replace p2=p2*`ratio'  // so that they have the same probability of getting benefit on average

*** Expected utilities under Scenario 1 and Scenario 2 ***
gen u_1 = p1*u_got + (1-p1)*u_not	// elite on
gen u_2 = p2*u_got + (1-p2)*u_not	// elite off



*****************************************************************
* f. Generate quota *********************************************

sum p2
local mean_p3=r(mean)
count
local sample_size=r(N)
local quota_temp=`mean_p3'*`sample_size'
local quota=round(`quota_temp')



*****************************************************************
* g. Scenario 3 *************************************************

sort PMTSCORE
gen getbenefit_3=(_n<=`quota')
gen u_3 = u_not if getbenefit_3==0
replace u_3 = u_got if getbenefit_3==1



*****************************************************************
* h. Scenario 4 *************************************************

sort logconsumption
gen getbenefit_4=(_n<=`quota')
gen u_4 = u_not if getbenefit_4==0
replace u_4 = u_got if getbenefit_4==1



*****************************************************************
* i. Scenario 5 *************************************************

g ppls08any = (klas_ppls!="")
gsort -ppls08any +PMTSCORE
g getbenefit_5=(_n<=`quota')
g u_5 = u_not if getbenefit_5==0
replace u_5 = u_got if getbenefit_5==1
count if klas_ppls!=""
local pplscount = `r(N)'



*****************************************************************
* j. Sums and differences in utilities **************************

*** Sum utilities ***
forv a = 0/5 {
	egen double sum_u`a'=sum(u_`a')	// social welfare
	replace sum_u`a'=sum_u`a'*(10^8)	// normalize
	local u`a' = sum_u`a'	// store
	}

*** Differences in utility ***
local temp = `u4' - `u0'     //utility under perfect targeting - utility with no program//
foreach a of numlist 1/3 5 {
	local temp`a' = (`u`a'' - `u0')    // scenario - no program
	local temp`a' = `temp`a''/`temp'	// as a percent of possible gain
	}



*****************************************************************
* k. Matrix for panel *******************************************

mat `i' = (`u0' \ `u1' \ `u2' \ `u3' \ `u4' \ `u5' \ `temp1' \ `temp2' \ `temp3' \ `temp5' )

restore
}	// ends elite-type loop




**************************************
*6. Combine matrices******************
**************************************

foreach x in B { // A B C { // only considering Formal Elites in final paper
	mat rownames `x' = WithoutProgram WithEliteOn WithEliteOff PerfectPMT PerfectConsumption PPLSThenPMT ShareWithEliteOn ShareWithEliteOff SharePerfectPMT SharePPLSThenPMT
	mat colnames `x' = PKH
	mat2txt, matrix(`x') saving("$output/tables/Appendix Table 4") replace
	}

clear

